"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ngAdd = void 0;
const schematics_1 = require("@angular-devkit/schematics");
const tasks_1 = require("@angular-devkit/schematics/tasks");
const package_config_1 = require("./package-config");
const pkgJson = require("../../package.json");
const addCoreUIIconsAngular = () => {
    return (tree, context) => {
        context.logger.info(`Installing @coreui/icons-angular as dependency`);
        context.addTask(new tasks_1.NodePackageInstallTask({ packageName: '@coreui/icons-angular' }));
        return tree;
    };
};
const addCoreUIAngular = () => {
    return (tree, context) => {
        context.logger.info(`Installing @coreui/angular as dependency`);
        context.addTask(new tasks_1.NodePackageInstallTask());
        return tree;
    };
};
function ngAdd() {
    return (tree, context) => {
        context.logger.info(``);
        context.logger.info('Installing @coreui/angular dependencies...');
        const ngCoreVersionTag = (0, package_config_1.getPackageVersionFromPackageJson)(tree, '@angular/core');
        context.logger.info(`@angular/core version ${ngCoreVersionTag}`);
        if (!ngCoreVersionTag) {
            throw new schematics_1.SchematicsException('@angular/core version not found');
        }
        const projDeps = ['@angular/animations', '@angular/common', '@angular/core', '@angular/router'];
        projDeps.forEach((dep) => {
            (0, package_config_1.addPackageToPackageJson)(tree, dep, ngCoreVersionTag);
        });
        const pkg = pkgJson;
        const libPeerDeps = ['@angular/cdk', '@coreui/coreui'];
        libPeerDeps.forEach((dep) => {
            const version = pkg.peerDependencies[dep];
            context.logger.info(`Including ${dep} version ${version}`);
            (0, package_config_1.addPackageToPackageJson)(tree, dep, version);
        });
        const libDeps = ['@popperjs/core'];
        libDeps.forEach((dep) => {
            const version = pkg.dependencies[dep];
            context.logger.info(`Including ${dep} version ${version}`);
            (0, package_config_1.addPackageToPackageJson)(tree, dep, version);
        });
        return (0, schematics_1.chain)([addCoreUIIconsAngular(), addCoreUIAngular()]);
    };
}
exports.ngAdd = ngAdd;
//# sourceMappingURL=index.js.map